@@ -3,50 +3,84 @@ import xlrd
 import openpyxl
 import os
 import shutil
+from openpyxl.utils import column_index_from_string
 
-def CheckEmail(email):
+def EmailFormatValidator(email):
+    """
+     Validates if an email address is in the correct format and returns a
+       PASS (email in correct format) or FAIL (email not in correct format)
+    """
     if re.match("[\.\w]{2,}[@]\w+[.]\w+",email,re.IGNORECASE):
     	 return "PASS"
     else:
          return "FAIL"
 
-def ContainsOnlyDigits(StrValue):
+def ContainsOnlyDigits(str_value):
+    """
+     Returns the count of the number of times a string value appears in a string
+       Returns PASS (str_value contains only digits) or FAIL (str_value does not
+       contain only digits)
+    """
     # Using regex() 
-    if re.match('^[0-9]*$', StrValue): 
+    if re.match('^[0-9]*$', str_value): 
        return   'PASS' 
     else: 
        return   'FAIL'
 
 def ConvertStringToList(string): 
+    """
+     Converts a string of values to an array to be used in a list variable
+    """
     ConvLst = list(string.split(" ")) 
     return ConvLst 
 
-def GetValueInString(Value, Str): 
-    Match = re.findall(Value, Str)
+def GetValueInString(Value, str): 
+    """
+     Returns the string (str) passed in if it is contained within the Value or Returns FAIL if the string
+       is not contained within the Value.
+    """
+    Match = re.findall(Value, str)
     if Match: 
        return    Match
     else: 
        return    'FAIL'
        
-def FormatValidator(FieldFormat, FieldValue): 
-    Regex_Match = re.match(FieldFormat, FieldValue)
+def FormatValidator(field_format, field_value): 
+    """
+     Returns PASS if the field_value matches a specified field format (field_format)
+     Returns FAIL if the field_value does not match a specified field format (field_format).
+    """
+    Regex_Match = re.match(field_format, field_value)
     if Regex_Match: 
        return    'PASS'
     else: 
        return    'FAIL'
 
 def GetStringPosition(str,fnd): 
+    """
+    Returns the index of the positive of a string (fnd) contained in the string value passed in (str)
+    """
     pos = 0
     ind = str.find(fnd)
     pos += str.find(fnd)
     return pos
 
-def GetUniqueItems(iterable):
-  for x in ints_list:
-      if ints_list.count(x) > 1:
-         ints_list.remove(x)
+def GetUniqueItems(list_values):
+  """
+  Returns the unique list of values from argument list_values
+  """
+  for x in list_values:
+      if list_values.count(x) > 1:
+         list_values.remove(x)
   return result
 
+def CountOccurenceOfValueInString(str, value):
+    """
+     Returns the count of the number of times a value appears in a string
+    """
+    ValueCount = String.Count(Vaue)
+    return ValueCount
+
 def DisposeWebDriver():
         """
         Closes the browser and shuts down the ChromeDriver executable
@@ -69,6 +103,9 @@ def DisposeWebDriver():
             pass
             
 def RemoveSpecialCharacters(str):
+     """
+     Removes special characters from a string
+     """
      alphanumeric = ""
      for character in str:
         if character.isalnum():
@@ -77,7 +114,9 @@ def RemoveSpecialCharacters(str):
 
 
 def CreateNewWorkbook(filename):
-    #Create workbook object
+    """
+    Creates a workbook object 
+    """
     wb = openpyxl.Workbook()
     #Create Sheet and sheetname
     ws = wb.create_sheet("Sheet Name", 0)
@@ -85,12 +124,17 @@ def CreateNewWorkbook(filename):
     
     
 def OpenWorkbook(filename):
-    #Open workbook
+    """
+    Opens a workbook
+    """
     wb = openpyxl.load_workbook(filename)
     for sheet in wb:
         print(sheet.title)
 
 def GetTestCaseDataRow(testnme, excel_col, fileName, sheetname) :
+    """
+    Returns a row of data from an excel file for a given test case name
+    """
     workbook = xlrd.open_workbook(fileName)
     worksheet = workbook.sheet_by_name(sheetname)
     rowEndIndex = worksheet.nrows - 1
@@ -119,13 +163,19 @@ def GetTestCaseDataRow(testnme, excel_col, fileName, sheetname) :
     return dataRow
            
 
-def GetDataRowCount(fileName, sheetname) :
+def GetDataRowCount(filename, sheetname) :
+    """
+    Returns the number rows in a particular sheetname of an excel file
+    """
     workbook = xlrd.open_workbook(fileName)
     worksheet = workbook.sheet_by_name(sheetname)
     rowEndIndex = worksheet.nrows - 1   
     return rowEndIndex
 
 def GetDataByRowIndex(excel_row, filename, sheetname) :
+    """
+    Return a row of data by the excel_row index passed in
+    """
     workbook = openpyxl.load_workbook(filename)
     worksheet =  workbook.get_sheet_by_name(sheetname)
     data_row = []                
@@ -136,25 +186,33 @@ def GetDataByRowIndex(excel_row, filename, sheetname) :
            data_row.append(cell.value)                                           	     
     return data_row  # return the row of test data
    
-def GetNextAvailableDataRow(filename,sheetname):
+def GetNextAvailableDataRow(filename, sheetname, used_col_letter):
+     """
+     Returns that next available row of data that is not marked as 'Used' in the column letter (example: A,B,C,etc.) 
+        that is passed in 
+     """
      wb = openpyxl.load_workbook(filename)
      ws =  wb.get_sheet_by_name(sheetname)
-     Available_Row = 0
-     data_row = []
-     i = 1    
-     for row in ws.iter_rows(min_row=1, max_col=ws.max_column, max_row=ws.max_row):
+     data_row = []                
+     excel_col_number = column_index_from_string(used_col_letter)  
+     i = 1
+     for row in ws.iter_rows(min_row=1, max_row=ws.max_row):
          i = i + 1 
-         if ws.cell(i, 26).value != "Used":
-            Available_Row = i
-            break   # exit for loop            
-     for row in ws.iter_rows(min_row=Available_Row, max_row=Available_Row):
-        for cell in row:
-           data_row.append(cell.value)   #Append column values to the data row list                                             	     
-     ws.cell(row=Available_Row, column=26).value = "Used" # Update 'Available Row' column cell value to 'Used'
-     wb.save(filename) # Save the workbook 
-     return data_row # return the row of data to the test case 
+         if ws.cell(i, excel_col_number).value != "Used": 
+           available_row = i
+           break # exit for loop
+     for row in ws.iter_rows(min_row=available_row, max_row=available_row):               
+         for cell in row:
+           #Append column values to the data row list
+           data_row.append(cell.value)  
+     ws.cell(row=available_row, column=excel_col_number).value = "Used" # Update 'Available Row' column cell value to 'Used'
+     wb.save(filename) # Save the workbook                                                	     
+     return data_row  # return the row of test data
 
 def GetAllDataFromExcelFile(fileName, sheetname) :
+    """
+    Returns all of the rows of data from a particular sheetname of an excel file
+    """
     workbook = xlrd.open_workbook(fileName)
     worksheet = workbook.sheet_by_name(sheetname)
     rowEndIndex = worksheet.nrows - 1
@@ -174,6 +232,4 @@ def GetAllDataFromExcelFile(fileName, sheetname) :
              cur_col+=1
          curr_row += 1
          testData.append(dataRow)
-    return dataRow
-        
-          
\ No newline at end of file
+    return dataRow
\ No newline at end of file
